@@ -5,7 +5,7 @@ use strict;
 use utf8;
 use Carp;
 
-our $VERSION = 'v2.1.3';
+our $VERSION = 'v2.2.0';
 
 use JSON::MaybeXS;
 use Scalar::Util qw( weaken refaddr );
@@ -18,10 +18,17 @@ sub new {
         free_id     => [],
         call        => {},
         id          => {},
+        lax_response_version => 0,
     };
     return bless $self, $class;
 }
 
+sub lax_response_version {
+    my ($self, $lax_response_version) = @_;
+    $self->{lax_response_version} = int($lax_response_version) if defined $lax_response_version;
+    return $self->{lax_response_version}
+} 
+
 sub batch {
     my ($self, @requests) = @_;
     my @call  = grep {ref}  @requests;
@@ -144,7 +151,7 @@ sub response {      ## no critic (ProhibitExcessComplexity RequireArgUnpacking)
     if (ref $response ne 'HASH') {
         return 'expect Object';
     }
-    if (!defined $response->{jsonrpc} || $response->{jsonrpc} ne '2.0') {
+    if (!$self->{lax_response_version} && (!defined $response->{jsonrpc} || $response->{jsonrpc} ne '2.0')) {
         return 'expect {jsonrpc}="2.0"';
     }
     if (!exists $response->{id} || ref $response->{id} || !defined $response->{id}) {
@@ -198,7 +205,7 @@ JSON::RPC2::Client - Transport-independent JSON-RPC 2.0 client
 
 =head1 VERSION
 
-This document describes JSON::RPC2::Client version v2.1.3
+This document describes JSON::RPC2::Client version v2.2.0
 
 
 =head1 SYNOPSIS
@@ -395,6 +402,24 @@ Return nothing.
 
 Return list with all currently pending $call's.
 
+=head2 lax_response_version
+
+    $setting = $client->lax_response_version(1);
+    $setting = $client->lax_response_version;
+
+    The JSON-RPC 2.0 Specification requires all response objects to have a
+    member C<jsonrpc> with the value of exactly C<2.0>.
+
+    Set and query whether the client is to enforce this requirement or whether
+    it is liberal in what it accepts.
+
+    Setting this mode allows responses to violate this requirement.
+    This mode is required by Shelly smart home devices, which miss the
+    C<jsonrpc> member in responses.
+
+    By default it is enforced.
+
+    L<https://www.jsonrpc.org/specification#response_object>
 
 =head1 SUPPORT
 
